module Devision
  module Models
  module Authenticatable

    extend ActiveSupport::Concern

    def self.required_fields(klass)
      []
    end


    module ClassMethods

      def find_first_by_auth_conditions(tainted_conditions, options = {})
        to_adapter.find_first(tainted_conditions.merge(options))
      end

      def find_or_initialize_with_error_by(attribute, value, error=:invalid)
        find_or_initialize_with_errors([attribute], { attribute => value }, error)
      end

      def find_or_initialize_with_errors(required_attributes, attributes, error=:invalid)
        attributes = attributes.slice(*required_attributes)
        attributes.delete_if { |key, value| value.blank? }

        if attributes.size == required_attributes.size
          record = find_first_by_auth_conditions(attributes)
        end

        unless record
          record = new
          required_attributes.each do |key|
            value = attributes[key]
            record.public_send("#{key}=", value)
            record.errors.add(key, value.present? ? error : :blank)
          end
        end

        record
      end

    end
  end
  end
end
