module Devision
  module Models
    module Tokenizable
      extend ActiveSupport::Concern

      # Fields required on the target Model
      def self.required_fields(klass)
        [:token]
      end

      included do
        attr_reader :raw_token
      end

      def generate_tokens
        raw, enc = Devision.token_generator.generate(self.class, :token)
        @raw_token = raw
        self.token = enc
      end

      def generate_tokens!
        generate_tokens && save(validate: false)
      end

      def clear_token
        @raw_token = nil
        self.token = nil
      end

      module ClassMethods

        def locate_record_by_token(original_raw_token)
          original_token     = original_raw_token
          saved_token = Devision.token_generator.digest(self, :token, original_token)

          tokenizable = find_or_initialize_with_error_by(:token, saved_token)
          tokenizable
        end
      end


    end # Tokenizable
  end # Models
end # Devision
