module Devision
  module Models

    module Validatable

      module Email
        def self.required_fields(klass)
          [:email]
        end

        def self.included(base)
          base.extend(ClassMethods)
          base.class_eval do
            validates_presence_of :email, if: :email_required?
            validates_uniqueness_of :email, allow_blank: true, if: :email_changed?
            validates_format_of :email, with: email_regexp, allow_blank: true, if: :email_changed?
          end

          def email_required?
            true
          end
        end

        module ClassMethods
          Devision::Models::Config.add_options(self, :email_regexp)
        end
      end

      module Password
        def self.required_fields(klass)
          [:password]
        end

        def self.included(base)

          base.extend(ClassMethods)
          base.class_eval do
            validates_presence_of :password, if: :password_required?
            validates_confirmation_of :password, if: :password_required?
            validates_length_of :password, within: password_range, allow_blank: true
          end
        end

        # Password/Confirmation combo is required for:
        # new records
        # whenever either password or password_confirmation is set
        private
          def password_required?
            !persisted? || !password.nil? || !password_confirmation.nil?
          end

        module ClassMethods
          Devision::Models::Config.add_options(self, :password_range)
        end
      end


    end
  end
end
